@@ -70,6 +70,7 @@ class Engine:
         pipeline: dict,
         root_pipeline_data: Optional[dict] = None,
         root_pipeline_context: Optional[dict] = None,
+        subprocess_context: Optional[dict] = None,
         **options
     ):
         """
@@ -81,20 +82,29 @@ class Engine:
         :type root_pipeline_data: dict
         :param root_pipeline_context 根流程上下文
         :type root_pipeline_context: dict
+        :param subprocess_context 子流程预置流程上下文
+        :type subprocess_context: dict
         """
 
         root_pipeline_data = {} if root_pipeline_data is None else root_pipeline_data
         root_pipeline_context = {} if root_pipeline_context is None else root_pipeline_context
+        subprocess_context = {} if subprocess_context is None else subprocess_context
         cycle_tolerate = options.get("cycle_tolerate", False)
         validator.validate_and_process_pipeline(pipeline, cycle_tolerate)
 
-        self.runtime.pre_prepare_run_pipeline(pipeline, root_pipeline_data, root_pipeline_context, **options)
+        self.runtime.pre_prepare_run_pipeline(
+            pipeline, root_pipeline_data, root_pipeline_context, subprocess_context, **options
+        )
 
-        process_id = self.runtime.prepare_run_pipeline(pipeline, root_pipeline_data, root_pipeline_context, **options)
+        process_id = self.runtime.prepare_run_pipeline(
+            pipeline, root_pipeline_data, root_pipeline_context, subprocess_context, **options
+        )
         # execute from start event
         self.runtime.execute(process_id, pipeline["start_event"]["id"])
 
-        self.runtime.post_prepare_run_pipeline(pipeline, root_pipeline_data, root_pipeline_context, **options)
+        self.runtime.post_prepare_run_pipeline(
+            pipeline, root_pipeline_data, root_pipeline_context, subprocess_context, **options
+        )
 
     def pause_pipeline(self, pipeline_id: str):
         """
